pub struct GetGammaEventsParamsBuilder { /* private fields */ }Expand description
Builder for GetGammaEventsParams.
Implementations
Sourceimpl GetGammaEventsParamsBuilder
impl GetGammaEventsParamsBuilder
Sourcepub fn active<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn active<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Compatibility filter retained from the legacy Gamma event query.
pub fn closed<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Sourcepub fn archived<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn archived<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Compatibility filter retained from the legacy Gamma event query.
pub fn id<VALUE: Into<Vec<u64>>>(&mut self, value: VALUE) -> &mut Self
pub fn slug<VALUE: Into<Vec<String>>>(&mut self, value: VALUE) -> &mut Self
pub fn live<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn featured<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn cyom<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn title_search<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn liquidity_min<VALUE: Into<Decimal>>(&mut self, value: VALUE) -> &mut Self
pub fn liquidity_max<VALUE: Into<Decimal>>(&mut self, value: VALUE) -> &mut Self
pub fn volume_min<VALUE: Into<Decimal>>(&mut self, value: VALUE) -> &mut Self
pub fn volume_max<VALUE: Into<Decimal>>(&mut self, value: VALUE) -> &mut Self
Sourcepub fn start_date_min<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn start_date_min<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
ISO 8601 date or RFC 3339 date-time.
Sourcepub fn start_date_max<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn start_date_max<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
ISO 8601 date or RFC 3339 date-time.
Sourcepub fn end_date_min<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn end_date_min<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
ISO 8601 date or RFC 3339 date-time.
Sourcepub fn end_date_max<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn end_date_max<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
ISO 8601 date or RFC 3339 date-time.
Sourcepub fn start_time_min<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn start_time_min<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
ISO 8601 date or RFC 3339 date-time.
Sourcepub fn start_time_max<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn start_time_max<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
ISO 8601 date or RFC 3339 date-time.
pub fn tag_id<VALUE: Into<Vec<u64>>>(&mut self, value: VALUE) -> &mut Self
pub fn tag_slug<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn exclude_tag_id<VALUE: Into<Vec<u64>>>( &mut self, value: VALUE, ) -> &mut Self
pub fn tag_match<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn series_id<VALUE: Into<Vec<u64>>>(&mut self, value: VALUE) -> &mut Self
pub fn game_id<VALUE: Into<Vec<u64>>>(&mut self, value: VALUE) -> &mut Self
Sourcepub fn event_date<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn event_date<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
ISO 8601 date or RFC 3339 date-time.
pub fn event_week<VALUE: Into<u32>>(&mut self, value: VALUE) -> &mut Self
pub fn featured_order<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn recurrence<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn created_by<VALUE: Into<Vec<String>>>( &mut self, value: VALUE, ) -> &mut Self
pub fn parent_event_id<VALUE: Into<u64>>(&mut self, value: VALUE) -> &mut Self
pub fn include_children<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn partner_slug<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn include_chat<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn include_template<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn include_best_lines<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
pub fn locale<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn order<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn ascending<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn limit<VALUE: Into<u32>>(&mut self, value: VALUE) -> &mut Self
Sourcepub fn offset<VALUE: Into<u32>>(&mut self, value: VALUE) -> &mut Self
pub fn offset<VALUE: Into<u32>>(&mut self, value: VALUE) -> &mut Self
Client-side initial offset. Keyset requests never send this field.
Sourcepub fn max_events<VALUE: Into<u32>>(&mut self, value: VALUE) -> &mut Self
pub fn max_events<VALUE: Into<u32>>(&mut self, value: VALUE) -> &mut Self
Client-side cap on total events to fetch across all pages.
Sourcepub fn build(
&self,
) -> Result<GetGammaEventsParams, GetGammaEventsParamsBuilderError>
pub fn build( &self, ) -> Result<GetGammaEventsParams, GetGammaEventsParamsBuilderError>