pub struct GetGammaMarketsParamsBuilder { /* private fields */ }Expand description
Builder for GetGammaMarketsParams.
Implementations
Sourceimpl GetGammaMarketsParamsBuilder
impl GetGammaMarketsParamsBuilder
pub fn active<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn closed<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn archived<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn id<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn limit<VALUE: Into<u32>>(&mut self, value: VALUE) -> &mut Self
pub fn offset<VALUE: Into<u32>>(&mut self, value: VALUE) -> &mut Self
pub fn order<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn ascending<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn slug<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Sourcepub fn clob_token_ids<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn clob_token_ids<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Comma-separated CLOB token IDs.
Sourcepub fn condition_ids<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn condition_ids<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Comma-separated condition IDs (max 100).
pub fn liquidity_num_min<VALUE: Into<f64>>(&mut self, value: VALUE) -> &mut Self
pub fn liquidity_num_max<VALUE: Into<f64>>(&mut self, value: VALUE) -> &mut Self
pub fn volume_num_min<VALUE: Into<f64>>(&mut self, value: VALUE) -> &mut Self
pub fn volume_num_max<VALUE: Into<f64>>(&mut self, value: VALUE) -> &mut Self
Sourcepub fn start_date_min<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn start_date_min<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
ISO 8601 date string.
Sourcepub fn start_date_max<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn start_date_max<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
ISO 8601 date string.
Sourcepub fn end_date_min<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn end_date_min<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
ISO 8601 date string.
Sourcepub fn end_date_max<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn end_date_max<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
ISO 8601 date string.
pub fn tag_id<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn rewards_min_size<VALUE: Into<f64>>(&mut self, value: VALUE) -> &mut Self
pub fn include_tag<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Sourcepub fn question_ids<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn question_ids<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Comma-separated question IDs.
pub fn game_id<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn sports_market_types<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
pub fn market_maker_address<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
Sourcepub fn max_markets<VALUE: Into<u32>>(&mut self, value: VALUE) -> &mut Self
pub fn max_markets<VALUE: Into<u32>>(&mut self, value: VALUE) -> &mut Self
Client-side cap on total markets to fetch across all pages. Not sent to the API, only used by the paginator to stop early. Each market produces 2 instruments (Yes/No outcomes).
Sourcepub fn build(
&self,
) -> Result<GetGammaMarketsParams, GetGammaMarketsParamsBuilderError>
pub fn build( &self, ) -> Result<GetGammaMarketsParams, GetGammaMarketsParamsBuilderError>